****************************************
Constructing different types of contours
****************************************

.. warning::
    Stay tuned! We are currently working on this chapter.
    In the meantime if you have any questions feel free to open an issue.
